"""
web2ldap plugin classes for Active Directory (see draft-armijo-ldap-syntax)

$Id: activedirectory.py,v 1.2 2004/06/16 09:55:51 michael Exp $
"""

from w2lapp.gui import DisplayDN

from w2lapp.schema.syntaxes import LDAPSyntax,Boolean,DistinguishedName,DirectoryString,GeneralizedTime,Integer,OctetString,syntax_registry

class DNWithOctetString(DistinguishedName):
  oid = '1.2.840.113556.1.4.903'
  desc = 'DNWithOctetString'

  def displayValue(self,sid,form,ls,dn,valueindex=0,commandbutton=0):
    octet_tag,count,octet_string,dn = self.attrValue.split(':')
    return ':'.join([
      octet_tag,count,octet_string,
      DisplayDN(sid,form,ls,dn,commandbutton=commandbutton)
    ])


class DNWithString(DNWithOctetString):
  oid = '1.2.840.113556.1.4.904'
  desc = 'DNWithString'


class MicrosoftLargeInteger(Integer):
  oid = '1.2.840.113556.1.4.906'
  desc = 'Integer guaranteed to support 64 bit numbers'


class ObjectSecurityDescriptor(OctetString):
  oid = '1.2.840.113556.1.4.907'
  desc = 'Object-Security-Descriptor'


syntax_registry.registerSyntaxClass(DNWithOctetString)
syntax_registry.registerSyntaxClass(DNWithString)
syntax_registry.registerSyntaxClass(MicrosoftLargeInteger)
syntax_registry.registerSyntaxClass(ObjectSecurityDescriptor)


# Work around for Active Directory of Windows 2000:
# Register syntaxes by odd names
syntax_registry.oid2syntax['Boolean'] = Boolean
syntax_registry.oid2syntax['DN'] = DistinguishedName
syntax_registry.oid2syntax['Integer'] = Integer
syntax_registry.oid2syntax['DirectoryString'] = DirectoryString
syntax_registry.oid2syntax['GeneralizedTime'] = GeneralizedTime

syntax_registry.registerAttrType(
  DistinguishedName.oid,[
    'configurationNamingContext',
    'defaultNamingContext',
    'dsServiceName',
    'rootDomainNamingContext',
    'schemaNamingContext',
  ]
)
